==> kdeaddons-3.1.tar.bz2: kdeaddons-3.1/noatun-plugins/wavecapture/wavecapture.h <==
/*
	Copyright (C) 2001 Matthias Kretz <kretz@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
/* $Id: wavecapture.h,v 1.3 2001/12/01 02:46:04 molnarc Exp $ */

#ifndef WAVECAPTURE_H
#define WAVECAPTURE_H

#include <noatun/plugin.h>
#include <artsmodules.h>

#include <string>

class QTimer;
namespace KIO { class Job; }

class WaveCapture : public QObject, public Plugin
{
Q_OBJECT
NOATUNPLUGIND

public:
	WaveCapture();
	virtual ~WaveCapture();

	void init();

protected slots:
	void toggle();
	void newSong();
	void stopped();
	void playing();
	void paused();
	void saveAs();
	void copyFinished( KIO::Job* );

private:
	void start();
	void stop();

	int pluginMenuItem;

	bool _enabled;
	enum Status { PAUSED, STOPPED, PLAYING };
	Status _status;

	Arts::Effect_WAVECAPTURE _capture;
	int _count;
	long _id;
	std::string _filename;

	QTimer* _timer;
	KIO::Job* m_job;
};

#endif

// vim:ts=4:sw=4

==> kdeaddons-3.4.2.tar.bz2: kdeaddons-3.4.2/noatun-plugins/wavecapture/wavecapture.h <==
/*
	Copyright (C) 2001 Matthias Kretz <kretz@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/
/* $Id: wavecapture.h 212185 2003-03-07 22:11:39Z waba $ */

#ifndef WAVECAPTURE_H
#define WAVECAPTURE_H

#include <noatun/plugin.h>
#include <artsmodules.h>

#include <string>

class QTimer;
namespace KIO { class Job; }

class WaveCapture : public QObject, public Plugin
{
Q_OBJECT
NOATUNPLUGIND

public:
	WaveCapture();
	virtual ~WaveCapture();

	void init();

protected slots:
	void toggle();
	void newSong();
	void stopped();
	void playing();
	void paused();
	void saveAs();
	void copyFinished( KIO::Job* );

private:
	void start();
	void stop();

	int pluginMenuItem;

	bool _enabled;
	enum Status { PAUSED, STOPPED, PLAYING };
	Status _status;

	Arts::Effect_WAVECAPTURE _capture;
	int _count;
	long _id;
	std::string _filename;

	QTimer* _timer;
	KIO::Job* m_job;
};

#endif

// vim:ts=4:sw=4
